@@ -1,6 +1,8 @@
-from django.conf.urls.defaults import *
+from __future__ import unicode_literals
+from django.conf.urls import patterns, url
 from django.http import HttpResponse
 
+
 def deeply_nested(request):
     return HttpResponse('deeply nested!')
 
